function [x,w]=trapezi_composta(N,a,b)

% Formula dei trapezi composta.

% input:
% N: numero di subintervalli
% a,b: estremi di integrazione
%
% output:
% x: nodi di integrazione (vettore colonna)
% w: pesi di integrazione (vettore colonna)

h=(b-a)/N;             % passo di integrazione
x=a:h:b; x=x';         % nodi di integrazione
w=ones(N+1,1);         % pesi di integrazione
w(1)=0.5; w(N+1)=0.5;  
w=w*h;